# -*- coding: utf-8 -*-
from setuphelpers import *


# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_name_x86 = "VC_redist.x86.exe"
bin_name_x64 = "VC_redist.x64.exe"
# bin_name_arm64 = 'VC_redist.arm64.exe'
silent_args = "/quiet /norestart"


def install():
    # Installing the package
    vers = control.version.split("-")[0]

    if force:
        print("Removing the software before installation since the install is forced")
        uninstall()

    if check_if_install_need("x86", vers):
        print("Installing: %s" % bin_name_x86)
        run('"%s" %s' % (bin_name_x86, silent_args))
        if check_if_install_need("x86", vers):
            error("The installation did not go well")

    if iswin64():
        if check_if_install_need("x64", vers):
            print("Installing: %s" % bin_name_x64)
            run('"%s" %s' % (bin_name_x64, silent_args))
            if check_if_install_need("x64", vers):
                error("The installation did not go well")


def uninstall():
    for ukey_x86 in installed_softwares("Microsoft Visual C++ 2015-2022 Redistributable (x86)"):
        print("Removing: %s (%s)" % (ukey_x86["name"], ukey_x86["version"]))
        run(uninstall_cmd(ukey_x86["key"]) + " /norestart")

    if iswin64():
        for ukey_x64 in installed_softwares("Microsoft Visual C++ 2015-2022 Redistributable (x64)"):
            print("Removing: %s (%s)" % (ukey_x64["name"], ukey_x64["version"]))
            run(uninstall_cmd(ukey_x64["key"]) + " /norestart")


def audit():
    vers = control.version.split("-")[0]

    err = False
    if iswin64():
        if check_if_install_need("x64", vers):
            print("Microsoft Visual C++ 2015-2022 Redistributable (x64) with min version %s not found" % vers)
            err = True
    if check_if_install_need("x86", vers):
        print("Microsoft Visual C++ 2015-2022 Redistributable (x86) with min version %s not found" % vers)
        err = True

    if err:
        return "ERROR"

    warn = False

    if iswin64():
        x64vers = installed_softwares("Microsoft Visual C++ 2015-2022 Redistributable (x64) -")[0]["version"]
        if Version(x64vers) > Version(vers):
            print("The version installed on the workstation is more recent (x64) ! %s" % x64vers)
            warn = True

    x86vers = installed_softwares("Microsoft Visual C++ 2015-2022 Redistributable (x86) -")[0]["version"]
    if Version(x86vers) > Version(vers):
        print("The version installed on the workstation is more recent (x86) ! %s " % x86vers)
        warn = True

    if warn:
        return "WARNING"

    return "OK"


def check_if_install_need(arch, vers):
    for soft in installed_softwares("Microsoft Visual C++ 2015-2022 Redistributable (%s) - " % arch):
        if Version(soft["version"], 3) >= Version(vers, 3):
            return False
    return True
